@@ -54,9 +54,11 @@ static DBusHandlerResult gs_listener_message_handler    (DBusConnection  *connec
                                                          DBusMessage     *message,
                                                          void            *user_data);
 
-#define GS_LISTENER_SERVICE   "org.gnome.screensaver"
-#define GS_LISTENER_PATH      "/org/gnome/screensaver"
-#define GS_LISTENER_INTERFACE "org.gnome.screensaver"
+#define GS_LISTENER_SERVICE   "org.gnome.ScreenSaver"
+#define GS_LISTENER_PATH      "/org/gnome/ScreenSaver"
+#define GS_LISTENER_INTERFACE "org.gnome.ScreenSaver"
+
+#define TYPE_MISMATCH_ERROR GS_LISTENER_INTERFACE ".TypeMismatch"
 
 #define GS_LISTENER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GS_TYPE_LISTENER, GSListenerPrivate))
 
@@ -397,6 +399,18 @@ gs_listener_get_activation_enabled (GSListener *listener)
         return listener->priv->activation_enabled;
 }
 
+gboolean
+gs_listener_is_inhibited (GSListener *listener)
+{
+        gboolean inhibited;
+
+        g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
+
+        inhibited = listener_is_inhibited (listener);
+
+        return inhibited;
+}
+
 void
 gs_listener_set_activation_enabled (GSListener *listener,
                                     gboolean    enabled)
@@ -591,7 +605,7 @@ raise_property_type_error (DBusConnection *connection,
         g_warning (buf);
 
         reply = dbus_message_new_error (in_reply_to,
-                                        "org.gnome.screensaver.TypeMismatch",
+                                        TYPE_MISMATCH_ERROR,
                                         buf);
         if (reply == NULL)
                 g_error ("No memory");
