@@ -137,16 +137,19 @@ gs_manager_set_throttle_enabled (GSManager *manager,
 
                 manager->priv->throttle_enabled = throttle_enabled;
 
-                for (l = manager->priv->jobs; l; l = l->next) {
-                        if (throttle_enabled) {
-                                gs_job_stop (GS_JOB (l->data));
-                        } else {
-                                gs_job_start (GS_JOB (l->data));
-                        }
-                }
+                if (! manager->priv->dialog_up) {
 
-                for (l = manager->priv->windows; l; l = l->next) {
-                        gs_window_clear (l->data);
+                        for (l = manager->priv->jobs; l; l = l->next) {
+                                if (throttle_enabled) {
+                                        gs_job_stop (GS_JOB (l->data));
+                                } else {
+                                        gs_job_start (GS_JOB (l->data));
+                                }
+                        }
+
+                        for (l = manager->priv->windows; l; l = l->next) {
+                                gs_window_clear (l->data);
+                        }
                 }
         }
 }
@@ -304,10 +307,6 @@ select_theme (GSManager *manager)
         if (manager->priv->saver_mode == GS_MODE_BLANK_ONLY)
                 return NULL;
 
-        if (manager->priv->saver_mode == GS_MODE_DONT_BLANK) {
-                return NULL;
-        }
-
         if (manager->priv->themes) {
                 int number = 0;
 
@@ -726,7 +725,11 @@ window_dialog_down_cb (GSWindow  *window,
 
         if (! manager->priv->throttle_enabled) {
                 for (l = manager->priv->jobs; l; l = l->next) {
-                        gs_job_suspend (GS_JOB (l->data), FALSE);
+                        if (gs_job_is_running (GS_JOB (l->data))) {
+                                gs_job_suspend (GS_JOB (l->data), FALSE);
+                        } else {
+                                gs_job_start (GS_JOB (l->data));
+                        }
                 }
         }
 
@@ -944,6 +947,8 @@ gs_manager_activate (GSManager *manager)
         if (! manager->priv->windows)
                 gs_manager_create (GS_MANAGER (manager));
 
+        manager->priv->active = TRUE;
+
         /* fade to black and show windows */
         do_fade = TRUE;
         if (do_fade) {
@@ -960,8 +965,6 @@ gs_manager_activate (GSManager *manager)
                 show_windows (manager->priv->windows);
         }
 
-        manager->priv->active = TRUE;
-
         return TRUE;
 }
 
@@ -1018,7 +1021,7 @@ gs_manager_set_active (GSManager *manager,
 }
 
 gboolean
-gs_manager_is_active (GSManager *manager)
+gs_manager_get_active (GSManager *manager)
 {
         g_return_val_if_fail (manager != NULL, FALSE);
         g_return_val_if_fail (GS_IS_MANAGER (manager), FALSE);
